@@ -47,6 +47,9 @@ private Q_SLOTS:
         QCOMPARE(db.get(5), QVector<quint64>() << 1 << 2 << 3);
         db.del(5, 2);
         QCOMPARE(db.get(5), QVector<quint64>() << 1 << 3);
+
+        QCOMPARE(db.get(4), QVector<quint64>());
+        QCOMPARE(db.get(6), QVector<quint64>());
     }
 
     void testIter() {
@@ -68,9 +71,27 @@ private Q_SLOTS:
             QCOMPARE(it->docId(), static_cast<quint64>(val));
         }
 
+        it = db.iter(10, MTimeDB::LessEqual);
+        QVERIFY(it);
+
+        result = {1, 2, 3, 4, 5, 6};
+        for (quint64 val : result) {
+            QCOMPARE(it->next(), static_cast<quint64>(val));
+            QCOMPARE(it->docId(), static_cast<quint64>(val));
+        }
+
         it = db.iter(7, MTimeDB::LessEqual);
         QVERIFY(it);
 
+        result = {1, 2, 3, 4};
+        for (quint64 val : result) {
+            QCOMPARE(it->next(), static_cast<quint64>(val));
+            QCOMPARE(it->docId(), static_cast<quint64>(val));
+        }
+
+        it = db.iter(6, MTimeDB::LessEqual);
+        QVERIFY(it);
+
         result = {1, 2, 3};
         for (quint64 val : result) {
             QCOMPARE(it->next(), static_cast<quint64>(val));
@@ -96,6 +117,13 @@ private Q_SLOTS:
             QCOMPARE(it->next(), static_cast<quint64>(val));
             QCOMPARE(it->docId(), static_cast<quint64>(val));
         }
+
+        // Empty range
+        it = db.iterRange(4, 4);
+        QVERIFY(!it);
+
+        it = db.iterRange(10, 20);
+        QVERIFY(!it);
     }
 
     void testSortedAndUnique()
@@ -132,6 +160,33 @@ private Q_SLOTS:
             }
         }
     }
+
+    void testBeginOfEpoch() {
+        MTimeDB db(MTimeDB::create(m_txn), m_txn);
+
+        db.put(0, 1);
+        db.put(0, 2);
+        db.put(0, 3);
+        db.put(1, 4);
+
+        QCOMPARE(db.get(0), QVector<quint64>({1, 2, 3}));
+        db.del(99, 2);
+        QCOMPARE(db.get(0), QVector<quint64>({1, 2, 3}));
+        QCOMPARE(db.get(1), QVector<quint64>({4}));
+        db.del(0, 2);
+        QCOMPARE(db.get(0), QVector<quint64>({1, 3}));
+
+        PostingIterator* it = db.iter(0, MTimeDB::LessEqual);
+        QVector<quint64> result;
+        while (it->next()) {
+            result.append(it->docId());
+        }
+        QCOMPARE(result, QVector<quint64>({1, 3}));
+
+        it = db.iter(1, MTimeDB::GreaterEqual);
+        QVERIFY(it->next());
+        QCOMPARE(it->docId(), 4);
+    }
 };
 
 QTEST_MAIN(MTimeDBTest)
